@@ -1,14 +1,14 @@
 from .utils import *
-def cameo_threshold(df_in,rule='ge',time='time', amptitude='modified_Lmax', event='is_event',threshold=86.0, correction_threshold=94.0, correction_offset=0.3, correction_interval=5.0):
+def cameo_threshold(raw_data,rule='>=',time='time', amptitude='modified_Lmax', event='is_event',threshold=86.0, correction_threshold=94.0, correction_offset=0.3, correction_interval=5.0):
     '''arguments:
         required:
-            df_in: 包含時間戳記,音量,事件標記三欄的DataFrame
+            raw_data: 至少包含時間戳記,音量,事件標記三欄的raw_data DataFrame
         optional:
             rule: 需求與閾值的關係
-                'g' : 需求大於閾值則標記
-                'ge': 需求大於等於閾值則標記
-                'le': 需求小於等於閾值則標記
-                'l' : 需求小於閾值則標記
+                '>' : 需求大於閾值則標記
+                '>=': 需求大於等於閾值則標記
+                '<=': 需求小於等於閾值則標記
+                '<' : 需求小於閾值則標記
             time: 含有時間戳記的欄位標題 預設為 'time'
             amptitude: 含有音量的欄位標題 預設為 'modified_Lmax'
             event: 含有事件標記的欄位標題 預設為 'is_event' 
@@ -25,6 +25,7 @@ def cameo_threshold(df_in,rule='ge',time='time', amptitude='modified_Lmax', even
                 'end_time':[],
                 'duration':[],
                 'is_correction':[]}
+    df_in = pd.DataFrame(raw_data)
     lst_time, lst_amptitude, lst_event = data_handler(df_in, time, amptitude, event)
     ts_start, ts_end, bool_is_event, bool_is_correction = event_init()
     float_max_correction_time, ts_correction_start, ts_correction_end = correction_time_init()
@@ -34,10 +35,8 @@ def cameo_threshold(df_in,rule='ge',time='time', amptitude='modified_Lmax', even
             if(ts_start==pd.Timestamp(0.0)):
                 ts_start = lst_time[i]
                 modified_Lmax_start = lst_amptitude[i]
-            if(bool_in_correction(lst_amptitude[i], correction_threshold, correction_offset)):
-                if(ts_correction_start==0.0):
-                    ts_correction_start = lst_time[i]
-            else:
+
+            if not(ts_correction_start!=0.0 and bool_in_correction(lst_amptitude[i], correction_threshold, correction_offset)):
                 ts_correction_start = lst_time[i]
 
             ts_correction_end = lst_time[i]
@@ -48,12 +47,14 @@ def cameo_threshold(df_in,rule='ge',time='time', amptitude='modified_Lmax', even
             if(lst_event[i]):
                 bool_is_event = True
                 dt_event_time = lst_time[i]
+
             ts_end = lst_time[i]
             modified_Lmax_end = lst_amptitude[i]
         else:
             if(bool_is_event):
                 bool_is_correction = (float_max_correction_time > correction_interval)
                 update_dict(dict_out, dt_event_time, ts_start, ts_end, bool_is_correction)
+            
             ts_start, ts_end, bool_is_event, bool_is_correction = event_init()
             float_max_correction_time, ts_correction_start, ts_correction_end = correction_time_init()
-    return pd.DataFrame(dict_out)
+    return pd.DataFrame(dict_out)
\ No newline at end of file
